EmuDeviceType

Enum EmuDeviceType 

#[repr(u8)]
pub enum EmuDeviceType { Dummy = 0, InterruptController = 1, Console = 2, IVCChannel = 10, GPPTRedistributor = 32, GPPTDistributor = 33, GPPTITS = 34, PPPTGlobal = 48, VirtioBlk = 225, VirtioNet = 226, VirtioConsole = 227, }
The type of Emulated Device.

Allocation scheme:

  • 0x00 - 0x1F: Special devices, and abstract device types that does not specify a concrete interface or implementation. The device objects created from these types depend on the target architecture and the specific implementation of the hypervisor.
  • 0x20 - 0x7F: Concrete emulated device types.
    • 0x20 - 0x2F: Interrupt controller devices.
    • 0x30 - 0x3F: Reserved for future use.
  • 0x80 - 0xDF: Reserved for future use.
  • 0xE0 - 0xEF: Virtio devices.
  • 0xF0 - 0xFF: Reserved for future use.

Variants



Dummy = 0

Dummy device type.



InterruptController = 1

Interrupt controller device, e.g. vGICv2 in aarch64, vLAPIC in x86.



Console = 2

Console (serial) device.



IVCChannel = 10

An emulated device that provides Inter-VM Communication (IVC) channel.

This device is used for communication between different VMs, the corresponding memory region of this device should be marked as Reserved in device tree or ACPI table.



GPPTRedistributor = 32

ARM GIC Partial Passthrough Redistributor device.



GPPTDistributor = 33

ARM GIC Partial Passthrough Distributor device.



GPPTITS = 34

ARM GIC Partial Passthrough Interrupt Translation Service device.



PPPTGlobal = 48

RISC-V PLIC Partial Passthrough Global device.



VirtioBlk = 225

Virtio block device.



VirtioNet = 226

Virtio net device.



VirtioConsole = 227

Virtio console device.

Implementations

Source

impl EmulatedDeviceType

Implementation of methods for EmulatedDeviceType.

pub fn removable(&self) -> bool

Returns true if the device is removable.

pub fn from_usize(value: usize) -> EmulatedDeviceType

Converts a usize value to an EmulatedDeviceType.